@@ -4,8 +4,7 @@ import numpy as np
 from ctgan import CTGAN # CTGANSynthesizer
 import matplotlib.pyplot as plt
 
-def expand_dataset(X, y, names, savepath, NX = 3, 
-epochs = 10, batch_size = 100, cuda = True, verbose = True):
+def expand_dataset(X, y, NX = 3, epochs = 10, batch_size = 100, cuda = True, verbose = True):
     '''
     use ctGAN to upsample
 
@@ -17,13 +16,9 @@ epochs = 10, batch_size = 100, cuda = True, verbose = True):
     for c in set(y):     
 
         Xc = X[y == c]
-
-        dfXc = pd.DataFrame(Xc)
-        dfXc.columns = list(np.array(names, dtype='str')) # ctgan requires string list headers
-        dfc = pd.concat([dfXc], axis=1)
-        
-        ctgan = CTGAN(epochs = epochs, batch_size = batch_size, cuda = cuda)
-        ctgan.fit(dfc, dfXc.columns)
+       
+        ctgan = CTGAN(generator_dim=(128,128), discriminator_dim=(128,128), epochs = epochs, batch_size = batch_size, cuda = cuda)
+        ctgan.fit(Xc, discrete_columns = [i for i in range(Xc.shape[1])])
 
         if verbose:
             print('--- ctgan trained for y = ' + str(c) + '---')
@@ -42,14 +37,4 @@ epochs = 10, batch_size = 100, cuda = True, verbose = True):
         Xnew = np.vstack((Xnew, Xce))
         ynew = ynew + [c]*len(y[y == c]) * NX
 
-    dfX = pd.DataFrame(Xnew)
-    dfX.columns = names
-
-    dfY = pd.DataFrame(np.array(ynew))
-    dfY.columns = ['label']
-
-    df = pd.concat([dfY, dfX], axis=1)
-    df = df.sort_values(by=['label'], ascending=True)
-    df.to_csv(savepath, index=False) # don't create the index column
-
     return Xnew,ynew
\ No newline at end of file
